@@ -576,3 +576,11 @@ class TestVies(TestCase):
             'street_and_num': 'Street 42 - 24/12',
             'city': 'City'
         })
+
+    def test_parse_address_at_two_lines(self):
+        data = parse_address('AT', 'Preston-Prest-Park 42\nAT-9182 City')
+        self.assertDictEqual(data, {
+            'street_and_num': 'Preston-Prest-Park 42',
+            'postal_code': 'AT-9182',
+            'city': 'City'
+        })
